@@ -29,7 +29,10 @@ __license__ = "MIT"
 __contributors__ = [
     "William Guilherme",
 ]
-__version__ = "0.5.2"
+__version__ = "0.9.2"
 
+from zscaler.zdx import ZDXClientHelper  # noqa
 from zscaler.zia import ZIAClientHelper  # noqa
 from zscaler.zpa import ZPAClientHelper  # noqa
+from zscaler.zcon import ZCONClientHelper  # noqa
+from zscaler.zcc import ZCCClientHelper  # noqa
