@@ -17,7 +17,7 @@
 import argparse
 import base64
 import datetime
-import json
+import functools
 import json as jsonp
 import logging
 import random
@@ -80,7 +80,10 @@ def snake_to_camel(name: str):
         "name_l10n_tag": "nameL10nTag",
         "surrogate_ip": "surrogateIP",
         "surrogate_ip_enforced_for_known_browsers": "surrogateIPEnforcedForKnownBrowsers",
+        "ec_vms": "ecVMs",
         "is_incomplete_dr_config": "isIncompleteDRConfig",
+        "ipv6_enabled": "ipV6Enabled",
+        "valid_ssl_certificate": "validSSLCertificate",
         "email_ids": "emailIds",
         "page_size": "pageSize",
     }
@@ -97,6 +100,22 @@ def recursive_snake_to_camel(data):
         return data
 
 
+def convert_keys(data, direction="to_camel"):
+    converter = camel_to_snake if direction == "to_snake" else snake_to_camel
+
+    if isinstance(data, (list, BoxList)):
+        return [convert_keys(inner_dict, direction=direction) for inner_dict in data]
+    elif isinstance(data, (dict, Box)):
+        new_dict = {}
+        for k in data.keys():
+            v = data[k]
+            new_key = converter(k)
+            new_dict[new_key] = convert_keys(v, direction=direction) if isinstance(v, (dict, list)) else v
+        return new_dict
+    else:
+        return data
+
+
 def chunker(lst, n):
     """Yield successive n-sized chunks from lst."""
     for i in range(0, len(lst), n):
@@ -147,26 +166,6 @@ def add_id_groups(id_groups: list, kwargs: dict, payload: dict):
     return
 
 
-# def transform_common_id_fields(id_groups: list, kwargs: dict, payload: dict):
-#     for entry in id_groups:
-#         if kwargs.get(entry[0]):
-#             # Ensure each ID is treated as an integer before adding it to the payload
-#             payload[entry[1]] = [{"id": int(param_id)} for param_id in kwargs.pop(entry[0])]
-#     return
-
-# ####### Function used in the ZIA Forwarding Control Rule #######
-# def transform_fwd_id_fields(id_groups: list, kwargs: dict, payload: dict):
-#     for entry in id_groups:
-#         key, payload_key = entry
-#         if key in kwargs:
-#             value = kwargs.pop(key)
-#             if isinstance(value, dict):
-#                 payload[payload_key] = {k: v for k, v in value.items() if k in ['id', 'name']}
-#             elif isinstance(value, list):
-#                 payload[payload_key] = [{"id": int(item)} if isinstance(item, str) and item.isdigit() else item for item in value]
-#     return
-
-
 def transform_common_id_fields(id_groups: list, kwargs: dict, payload: dict):
     for entry in id_groups:
         key, payload_key = entry
@@ -182,6 +181,14 @@ def transform_common_id_fields(id_groups: list, kwargs: dict, payload: dict):
                 # Handle zpa_app_segments, zpa_application_segments, and zpa_application_segment_groups
                 if isinstance(value, list):
                     payload[payload_key] = [{"externalId": item["external_id"], "name": item["name"]} for item in value]
+            elif key == "cbi_profile":
+                # Special handling for cbi_profile
+                if isinstance(value, dict) and all(k in value for k in ["id", "name", "url"]):
+                    payload[payload_key] = {"id": value["id"], "name": value["name"], "url": value["url"]}
+            elif key == "cloud_app_risk_profile":
+                # Special handling for cloudAppRiskProfile
+                if isinstance(value, dict) and "id" in value:
+                    payload[payload_key] = {"id": value["id"]}
             else:
                 # General case for ID transformations
                 if isinstance(value, list):
@@ -343,6 +350,208 @@ class Iterator(APIIterator):
             time.sleep(1)
 
 
+def calculate_epoch(hours: int):
+    current_time = int(time.time())
+    past_time = int(current_time - (hours * 3600))
+    return current_time, past_time
+
+
+def zdx_params(func):
+    """
+    Decorator to add custom parameter functionality for ZDX API calls.
+
+    Args:
+        func: The function to decorate.
+
+    Returns:
+        The decorated function.
+
+    """
+
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs):
+        since = kwargs.pop("since", None)
+        search = kwargs.pop("search", None)
+        location_id = kwargs.pop("location_id", None)
+        department_id = kwargs.pop("department_id", None)
+        geo_id = kwargs.pop("geo_id", None)
+
+        if since:
+            current_time, past_time = calculate_epoch(since)
+            kwargs["to"] = current_time
+            kwargs["from"] = past_time
+
+        kwargs["q"] = search or kwargs.get("q")
+        kwargs["loc"] = location_id or kwargs.get("loc")
+        kwargs["dept"] = department_id or kwargs.get("dept")
+        kwargs["geo"] = geo_id or kwargs.get("geo")
+
+        return func(self, *args, **kwargs)
+
+    return wrapper
+
+
+class CommonFilters:
+    def __init__(self, **kwargs):
+        valid_params = {
+            "from_time": None,
+            "to": None,
+            "score_bucket": None,
+            "app_id": None,
+            "loc": None,
+            "exclude_loc": None,
+            "dept": None,
+            "exclude_dept": None,
+            "geo": None,
+            "exclude_geo": None,
+            "offset": None,
+            "limit": None,
+        }
+
+        for key, value in kwargs.items():
+            if key in valid_params:
+                setattr(self, key, value)
+
+    def to_dict(self):
+        return {
+            k: v
+            for k, v in {
+                "from": getattr(self, "from_time", None),
+                "to": getattr(self, "to", None),
+                "score_bucket": getattr(self, "score_bucket", None),
+                "app_id": getattr(self, "app_id", None),
+                "loc": getattr(self, "loc", None),
+                "exclude_loc": getattr(self, "exclude_loc", None),
+                "dept": getattr(self, "dept", None),
+                "exclude_dept": getattr(self, "exclude_dept", None),
+                "geo": getattr(self, "geo", None),
+                "exclude_geo": getattr(self, "exclude_geo", None),
+                "offset": getattr(self, "offset", None),
+                "limit": getattr(self, "limit", None),
+            }.items()
+            if v is not None
+        }
+
+
+class ZDXIterator:
+    def __init__(self, client, endpoint, filters=None):
+        self.client = client
+        self.endpoint = endpoint
+        self.filters = {k: v for k, v in (filters or {}).items() if v is not None}
+        self.next_offset = None
+        self.previous_offset = None
+        self.page = []
+        self.page_count = 0
+        self.total = 0
+        self.logger = logging.getLogger("zscaler-sdk-python")
+        self._get_page()
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self.page_count >= len(self.page):
+            if self.next_offset is None:
+                raise StopIteration
+            if self.next_offset == self.previous_offset:
+                self.logger.warning(
+                    f"Detected repeated next_offset: {self.next_offset}, stopping iteration to avoid infinite loop."
+                )
+                raise StopIteration
+            self.previous_offset = self.next_offset
+            self._get_page()
+            if not self.page:
+                raise StopIteration
+        item = self.page[self.page_count]
+        self.page_count += 1
+        return item
+
+    def _get_page(self):
+        params = {**self.filters, "offset": self.next_offset} if self.next_offset else self.filters
+        response = self.client.get(self.endpoint, params=params)
+
+        self.logger.debug(f"API response: {response}")
+
+        if response is None:
+            self.logger.error(f"Invalid response: {response}")
+            raise StopIteration
+
+        if isinstance(response, list):
+            self.page = response
+            self.next_offset = None
+        elif isinstance(response, dict):
+            self.next_offset = response.get("next_offset")
+            self.page = (
+                response.get("alerts", [])
+                or response.get("items", [])
+                or response.get("devices", [])
+                or response.get("probes", [])
+                or response.get("software", [])
+            )
+        else:
+            self.logger.error(f"Unexpected response type: {type(response)}")
+            raise StopIteration
+
+        if not self.page:
+            self.next_offset = None
+
+        self.total += len(self.page)
+        self.page_count = 0
+
+
+# class ZDXIterator:
+#     def __init__(self, client, endpoint, filters=None):
+#         self.client = client
+#         self.endpoint = endpoint
+#         self.filters = {k: v for k, v in (filters or {}).items() if v is not None}
+#         self.next_offset = None
+#         self.page = []
+#         self.page_count = 0
+#         self.total = 0
+#         self.logger = logging.getLogger("zscaler-sdk-python")
+#         self._get_page()
+
+#     def __iter__(self):
+#         return self
+
+#     def __next__(self):
+#         if self.page_count >= len(self.page):
+#             if self.next_offset is None:
+#                 raise StopIteration
+#             self._get_page()
+#             if not self.page:
+#                 raise StopIteration
+#         item = self.page[self.page_count]
+#         self.page_count += 1
+#         return item
+
+#     def _get_page(self):
+#         params = {**self.filters, "offset": self.next_offset} if self.next_offset else self.filters
+#         response = self.client.get(self.endpoint, params=params)
+
+#         self.logger.debug(f"API response: {response}")
+
+#         if response is None:
+#             self.logger.error(f"Invalid response: {response}")
+#             raise StopIteration
+
+#         if isinstance(response, list):
+#             self.page = response
+#             self.next_offset = None
+#         elif isinstance(response, dict):
+#             self.next_offset = response.get("next_offset")
+#             self.page = response.get("devices", []) or response.get("items", []) or response.get("probes", [])
+#         else:
+#             self.logger.error(f"Unexpected response type: {type(response)}")
+#             raise StopIteration
+
+#         if not self.page:
+#             self.next_offset = None
+
+#         self.total += len(self.page)
+#         self.page_count = 0
+
+
 def remove_cloud_suffix(str_name: str) -> str:
     """
     Removes appended cloud name (e.g. "(zscalerthree.net)") from the string.
@@ -516,6 +725,26 @@ def validate_and_convert_times(start_time_str, end_time_str, time_zone_str):
     return start_epoch, end_epoch
 
 
+# Maps ZCC numeric os_type and registration_type arguments to a human-readable string
+zcc_param_map = {
+    "os": {
+        "ios": 1,
+        "android": 2,
+        "windows": 3,
+        "macos": 4,
+        "linux": 5,
+    },
+    "reg_type": {
+        "all": 0,
+        "registered": 1,
+        "removal_pending": 3,
+        "unregistered": 4,
+        "removed": 5,
+        "quarantined": 6,
+    },
+}
+
+
 def dump_request(logger, url: str, method: str, json, params, headers, request_uuid: str, body=True):
     request_headers_filtered = {key: value for key, value in headers.items() if key != "Authorization"}
     # Log the request details before sending the request
